[![badge doc](https://img.shields.io/badge/docs-v0.1.5-orange.svg)](https://www.idiap.ch/software/bob/docs/bob/bob.fusion.base/v0.1.5/sphinx/index.html)
[![badge pipeline](https://gitlab.idiap.ch/bob/bob.fusion.base/badges/v0.1.5/pipeline.svg)](https://gitlab.idiap.ch/bob/bob.fusion.base/commits/v0.1.5)
[![badge coverage](https://gitlab.idiap.ch/bob/bob.fusion.base/badges/v0.1.5/coverage.svg)](https://www.idiap.ch/software/bob/docs/bob/bob.fusion.base/v0.1.5/coverage/)
[![badge gitlab](https://img.shields.io/badge/gitlab-project-0000c0.svg)](https://gitlab.idiap.ch/bob/bob.fusion.base)

# Score Fusion in Biometric Recognition and Presentation Attack Detection

This package is part of the signal-processing and machine learning toolbox
[Bob](https://www.idiap.ch/software/bob). It runs score fusion in biometric and
presentation attack detection experiments using various algorithms. It provides
several algorithms and scripts to be used for running and reporting fusion
experiments.

## Installation

Complete Bob's
[installation instructions](https://www.idiap.ch/software/bob/install). Then,
to install this package, run:

``` sh
conda install bob.fusion.base
```

## Contact

For questions or reporting issues to this software package, contact our
development [mailing list](https://www.idiap.ch/software/bob/discuss).
